pub fn _blcfill_u32(x: u32) -> u32Available on target feature
tbm and (x86 or x86-64) only.Expand description
Clears all bits below the least significant zero bit of x.
If there is no zero bit in x, it returns zero.