pub fn _blcic_u32(x: u32) -> u32Available on target feature
tbm and (x86 or x86-64) only.Expand description
Sets the least significant zero bit of x and clears all other bits.
If there is no zero bit in x, it returns zero.