pub fn _blsfill_u32(x: u32) -> u32Available on target feature
tbm and (x86 or x86-64) only.Expand description
Sets all bits of x below the least significant one.
If there is no set bit in x, it sets all the bits.